/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 5.04                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Renesas RH850/F1x StarterKit V2/V3
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "device.h"  // Device specific header file, contains Port Group Configuration Registers definitions

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define NUM_LEDS  (2u)  // LED1 and LED2 are used

/*********************************************************************
*
*       Typedefs
*
**********************************************************************
*/

typedef struct _LED_INFO {
  unsigned int           PortPin;   // Pin number
  volatile unsigned int* pReg_PMC;  // Port mode control register
  volatile unsigned int* pReg_PM;   // Port mode register
  volatile unsigned int* pReg_P;    // Port register
} LED_INFO;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/

static LED_INFO _aLEDInfo[] = {
  { 11u, (volatile unsigned int*)&PMC0, (volatile unsigned int*)&PM0, (volatile unsigned int*)&P0 },  // LED1: Port 0, Pin 11
  {  5u, (volatile unsigned int*)&PMC8, (volatile unsigned int*)&PM8, (volatile unsigned int*)&P8 }   // LED2: Port 8, Pin  5
};

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  int Index;

  for (Index = 0; Index < (int)NUM_LEDS; Index++) {
    *(_aLEDInfo[Index].pReg_PMC) &= ~(1u << _aLEDInfo[Index].PortPin);  // Select port mode
    *(_aLEDInfo[Index].pReg_PM)  &= ~(1u << _aLEDInfo[Index].PortPin);  // Select output mode
    *(_aLEDInfo[Index].pReg_P)   &= ~(1u << _aLEDInfo[Index].PortPin);  // Initially set output low
  }
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < (int)NUM_LEDS) {
    *(_aLEDInfo[Index].pReg_P) |= (1u << _aLEDInfo[Index].PortPin);  // Set output high
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < (int)NUM_LEDS) {
    *(_aLEDInfo[Index].pReg_P) &= ~(1u << _aLEDInfo[Index].PortPin);  // Set output low
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < (int)NUM_LEDS) {
    if (*(_aLEDInfo[Index].pReg_P) & (1u << _aLEDInfo[Index].PortPin)) {
      *(_aLEDInfo[Index].pReg_P) &= ~(1u << _aLEDInfo[Index].PortPin);  // Set output low
    } else {
      *(_aLEDInfo[Index].pReg_P) |=  (1u << _aLEDInfo[Index].PortPin);  // Set output high
    }
  }
}

/****** End Of File *************************************************/
